==> ambition_permissions-0.1.27-py3-none-any.whl: ambition_permissions/codenames/clinic.py <==
from edc_permissions.codenames import clinic

clinic += [
    "ambition_ae.add_aefollowup",
    "ambition_ae.add_aeinitial",
    "ambition_ae.add_aesusar",
    "ambition_ae.add_antibiotictreatment",
    "ambition_ae.add_meningitissymptom",
    "ambition_ae.add_neurological",
    "ambition_ae.add_recurrencesymptom",
    "ambition_ae.change_aefollowup",
    "ambition_ae.change_aeinitial",
    "ambition_ae.change_aesusar",
    "ambition_ae.change_antibiotictreatment",
    "ambition_ae.change_meningitissymptom",
    "ambition_ae.change_neurological",
    "ambition_ae.change_recurrencesymptom",
    "ambition_ae.delete_aefollowup",
    "ambition_ae.delete_aeinitial",
    "ambition_ae.delete_aesusar",
    "ambition_ae.delete_antibiotictreatment",
    "ambition_ae.delete_meningitissymptom",
    "ambition_ae.delete_neurological",
    "ambition_ae.delete_recurrencesymptom",
    "ambition_ae.view_aefollowup",
    "ambition_ae.view_aeinitial",
    "ambition_ae.view_aesusar",
    "ambition_ae.view_aetmg",
    "ambition_ae.view_antibiotictreatment",
    "ambition_ae.view_historicalaefollowup",
    "ambition_ae.view_historicalaeinitial",
    "ambition_ae.view_historicalaesusar",
    "ambition_ae.view_historicalaetmg",
    "ambition_ae.view_historicalrecurrencesymptom",
    "ambition_ae.view_meningitissymptom",
    "ambition_ae.view_neurological",
    "ambition_ae.view_recurrencesymptom",
    "ambition_lists.view_abnormalresultsreason",
    "ambition_lists.view_aeclassification",
    "ambition_lists.view_antibiotic",
    "ambition_lists.view_arvregimens",
    "ambition_lists.view_causeofdeath",
    "ambition_lists.view_cxrtype",
    "ambition_lists.view_day14medication",
    "ambition_lists.view_infiltratelocation",
    "ambition_lists.view_medication",
    "ambition_lists.view_misseddoses",
    "ambition_lists.view_neurological",
    "ambition_lists.view_otherdrug",
    "ambition_lists.view_saereason",
    "ambition_lists.view_significantnewdiagnosis",
    "ambition_lists.view_symptom",
    "ambition_prn.add_amphotericinmisseddoses",
    "ambition_prn.add_deathreport",
    "ambition_prn.add_deathreporttmgsecond",
    "ambition_prn.add_fluconazolemisseddoses",
    "ambition_prn.add_flucytosinemisseddoses",
    "ambition_prn.add_onschedule",
    "ambition_prn.add_onschedulew10",
    "ambition_prn.add_protocoldeviationviolation",
    "ambition_prn.add_significantdiagnoses",
    "ambition_prn.add_studyterminationconclusion",
    "ambition_prn.add_studyterminationconclusionw10",
    "ambition_prn.change_amphotericinmisseddoses",
    "ambition_prn.change_deathreport",
    "ambition_prn.change_deathreporttmgsecond",
    "ambition_prn.change_fluconazolemisseddoses",
    "ambition_prn.change_flucytosinemisseddoses",
    "ambition_prn.change_onschedule",
    "ambition_prn.change_onschedulew10",
    "ambition_prn.change_protocoldeviationviolation",
    "ambition_prn.change_significantdiagnoses",
    "ambition_prn.change_studyterminationconclusion",
    "ambition_prn.change_studyterminationconclusionw10",
    "ambition_prn.delete_amphotericinmisseddoses",
    "ambition_prn.delete_deathreport",
    "ambition_prn.delete_deathreporttmgsecond",
    "ambition_prn.delete_fluconazolemisseddoses",
    "ambition_prn.delete_flucytosinemisseddoses",
    "ambition_prn.delete_onschedule",
    "ambition_prn.delete_onschedulew10",
    "ambition_prn.delete_protocoldeviationviolation",
    "ambition_prn.delete_significantdiagnoses",
    "ambition_prn.delete_studyterminationconclusion",
    "ambition_prn.delete_studyterminationconclusionw10",
    "ambition_prn.view_amphotericinmisseddoses",
    "ambition_prn.view_deathreport",
    "ambition_prn.view_deathreporttmgsecond",
    "ambition_prn.view_fluconazolemisseddoses",
    "ambition_prn.view_flucytosinemisseddoses",
    "ambition_prn.view_historicalamphotericinmisseddoses",
    "ambition_prn.view_historicaldeathreport",
    "ambition_prn.view_historicaldeathreporttmg",
    "ambition_prn.view_historicaldeathreporttmgsecond",
    "ambition_prn.view_historicalfluconazolemisseddoses",
    "ambition_prn.view_historicalflucytosinemisseddoses",
    "ambition_prn.view_historicalonschedule",
    "ambition_prn.view_historicalonschedulew10",
    "ambition_prn.view_historicalprotocoldeviationviolation",
    "ambition_prn.view_historicalsignificantdiagnoses",
    "ambition_prn.view_historicalstudyterminationconclusion",
    "ambition_prn.view_historicalstudyterminationconclusionw10",
    "ambition_prn.view_onschedule",
    "ambition_prn.view_onschedulew10",
    "ambition_prn.view_protocoldeviationviolation",
    "ambition_prn.view_significantdiagnoses",
    "ambition_prn.view_studyterminationconclusion",
    "ambition_prn.view_studyterminationconclusionw10",
    "ambition_subject.add_amphotericinmisseddoses",
    "ambition_subject.add_bloodresult",
    "ambition_subject.add_education",
    "ambition_subject.add_educationhoh",
    "ambition_subject.add_fluconazolemisseddoses",
    "ambition_subject.add_flucytosinemisseddoses",
    "ambition_subject.add_followup",
    "ambition_subject.add_followupdiagnoses",
    "ambition_subject.add_lumbarpuncturecsf",
    "ambition_subject.add_medicalexpenses",
    "ambition_subject.add_medicalexpensestwo",
    "ambition_subject.add_medicalexpensestwodetail",
    "ambition_subject.add_microbiology",
    "ambition_subject.add_patienthistory",
    "ambition_subject.add_pkpdcrf",
    "ambition_subject.add_pkpdextrasamples",
    "ambition_subject.add_previousopportunisticinfection",
    "ambition_subject.add_radiology",
    "ambition_subject.add_significantdiagnoses",
    "ambition_subject.add_subjectrequisition",
    "ambition_subject.add_subjectvisit",
    "ambition_subject.add_week16",
    "ambition_subject.add_week2",
    "ambition_subject.add_week4",
    "ambition_subject.add_week4diagnoses",
    "ambition_subject.change_amphotericinmisseddoses",
    "ambition_subject.change_bloodresult",
    "ambition_subject.change_education",
    "ambition_subject.change_educationhoh",
    "ambition_subject.change_fluconazolemisseddoses",
    "ambition_subject.change_flucytosinemisseddoses",
    "ambition_subject.change_followup",
    "ambition_subject.change_followupdiagnoses",
    "ambition_subject.change_lumbarpuncturecsf",
    "ambition_subject.change_medicalexpenses",
    "ambition_subject.change_medicalexpensestwo",
    "ambition_subject.change_medicalexpensestwodetail",
    "ambition_subject.change_microbiology",
    "ambition_subject.change_patienthistory",
    "ambition_subject.change_pkpdcrf",
    "ambition_subject.change_pkpdextrasamples",
    "ambition_subject.change_previousopportunisticinfection",
    "ambition_subject.change_radiology",
    "ambition_subject.change_significantdiagnoses",
    "ambition_subject.change_subjectrequisition",
    "ambition_subject.change_subjectvisit",
    "ambition_subject.change_week16",
    "ambition_subject.change_week2",
    "ambition_subject.change_week4",
    "ambition_subject.change_week4diagnoses",
    "ambition_subject.delete_amphotericinmisseddoses",
    "ambition_subject.delete_bloodresult",
    "ambition_subject.delete_education",
    "ambition_subject.delete_educationhoh",
    "ambition_subject.delete_fluconazolemisseddoses",
    "ambition_subject.delete_flucytosinemisseddoses",
    "ambition_subject.delete_followup",
    "ambition_subject.delete_followupdiagnoses",
    "ambition_subject.delete_lumbarpuncturecsf",
    "ambition_subject.delete_medicalexpenses",
    "ambition_subject.delete_medicalexpensestwo",
    "ambition_subject.delete_medicalexpensestwodetail",
    "ambition_subject.delete_microbiology",
    "ambition_subject.delete_patienthistory",
    "ambition_subject.delete_pkpdcrf",
    "ambition_subject.delete_pkpdextrasamples",
    "ambition_subject.delete_previousopportunisticinfection",
    "ambition_subject.delete_radiology",
    "ambition_subject.delete_significantdiagnoses",
    "ambition_subject.delete_subjectrequisition",
    "ambition_subject.delete_subjectvisit",
    "ambition_subject.delete_week16",
    "ambition_subject.delete_week2",
    "ambition_subject.delete_week4",
    "ambition_subject.delete_week4diagnoses",
    "ambition_subject.view_amphotericinmisseddoses",
    "ambition_subject.view_bloodresult",
    "ambition_subject.view_education",
    "ambition_subject.view_educationhoh",
    "ambition_subject.view_fluconazolemisseddoses",
    "ambition_subject.view_flucytosinemisseddoses",
    "ambition_subject.view_followup",
    "ambition_subject.view_followupdiagnoses",
    "ambition_subject.view_historicalamphotericinmisseddoses",
    "ambition_subject.view_historicalbloodresult",
    "ambition_subject.view_historicaleducation",
    "ambition_subject.view_historicaleducationhoh",
    "ambition_subject.view_historicalfluconazolemisseddoses",
    "ambition_subject.view_historicalflucytosinemisseddoses",
    "ambition_subject.view_historicalfollowup",
    "ambition_subject.view_historicalfollowupdiagnoses",
    "ambition_subject.view_historicallumbarpuncturecsf",
    "ambition_subject.view_historicalmedicalexpenses",
    "ambition_subject.view_historicalmedicalexpensestwo",
    "ambition_subject.view_historicalmedicalexpensestwodetail",
    "ambition_subject.view_historicalmicrobiology",
    "ambition_subject.view_historicalpatienthistory",
    "ambition_subject.view_historicalpkpdcrf",
    "ambition_subject.view_historicalpkpdextrasamples",
    "ambition_subject.view_historicalpreviousopportunisticinfection",
    "ambition_subject.view_historicalradiology",
    "ambition_subject.view_historicalsignificantdiagnoses",
    "ambition_subject.view_historicalsubjectrequisition",
    "ambition_subject.view_historicalsubjectvisit",
    "ambition_subject.view_historicalweek16",
    "ambition_subject.view_historicalweek2",
    "ambition_subject.view_historicalweek4",
    "ambition_subject.view_historicalweek4diagnoses",
    "ambition_subject.view_lumbarpuncturecsf",
    "ambition_subject.view_medicalexpenses",
    "ambition_subject.view_medicalexpensestwo",
    "ambition_subject.view_medicalexpensestwodetail",
    "ambition_subject.view_microbiology",
    "ambition_subject.view_patienthistory",
    "ambition_subject.view_pkpdcrf",
    "ambition_subject.view_pkpdextrasamples",
    "ambition_subject.view_previousopportunisticinfection",
    "ambition_subject.view_radiology",
    "ambition_subject.view_significantdiagnoses",
    "ambition_subject.view_subjectrequisition",
    "ambition_subject.view_subjectvisit",
    "ambition_subject.view_week16",
    "ambition_subject.view_week2",
    "ambition_subject.view_week4",
    "ambition_subject.view_week4diagnoses",
    "edc_dashboard.view_ae_listboard",
    "edc_dashboard.view_screening_listboard",
    "edc_dashboard.view_subject_listboard",
    "edc_dashboard.view_tmg_listboard",
    "edc_navbar.nav_ae_section",
    "edc_navbar.nav_screening_section",
    "edc_navbar.nav_subject_section",
    "edc_navbar.nav_tmg_section",
]
clinic.sort()

==> ambition_permissions-0.1.28-py3-none-any.whl: ambition_permissions/codenames/clinic.py <==
from edc_permissions.codenames import clinic

clinic += [
    "ambition_ae.add_aefollowup",
    "ambition_ae.add_aeinitial",
    "ambition_ae.add_aesusar",
    "ambition_ae.add_antibiotictreatment",
    "ambition_ae.add_deathreport",
    "ambition_ae.add_meningitissymptom",
    "ambition_ae.add_neurological",
    "ambition_ae.add_recurrencesymptom",
    "ambition_ae.change_aefollowup",
    "ambition_ae.change_aeinitial",
    "ambition_ae.change_aesusar",
    "ambition_ae.change_antibiotictreatment",
    "ambition_ae.change_deathreport",
    "ambition_ae.change_meningitissymptom",
    "ambition_ae.change_neurological",
    "ambition_ae.change_recurrencesymptom",
    "ambition_ae.delete_aefollowup",
    "ambition_ae.delete_aeinitial",
    "ambition_ae.delete_aesusar",
    "ambition_ae.delete_antibiotictreatment",
    "ambition_ae.delete_deathreport",
    "ambition_ae.delete_meningitissymptom",
    "ambition_ae.delete_neurological",
    "ambition_ae.delete_recurrencesymptom",
    "ambition_ae.view_aefollowup",
    "ambition_ae.view_aeinitial",
    "ambition_ae.view_aesusar",
    "ambition_ae.view_aetmg",
    "ambition_ae.view_antibiotictreatment",
    "ambition_ae.view_deathreport",
    "ambition_ae.view_deathreporttmg",
    "ambition_ae.view_deathreporttmgsecond",
    "ambition_ae.view_historicalaefollowup",
    "ambition_ae.view_historicalaeinitial",
    "ambition_ae.view_historicalaesusar",
    "ambition_ae.view_historicalaetmg",
    "ambition_ae.view_historicaldeathreport",
    "ambition_ae.view_historicaldeathreporttmg",
    "ambition_ae.view_historicaldeathreporttmgsecond",
    "ambition_ae.view_historicalrecurrencesymptom",
    "ambition_ae.view_meningitissymptom",
    "ambition_ae.view_neurological",
    "ambition_ae.view_recurrencesymptom",
    "ambition_lists.view_abnormalresultsreason",
    "ambition_lists.view_aeclassification",
    "ambition_lists.view_antibiotic",
    "ambition_lists.view_arvregimens",
    "ambition_lists.view_causeofdeath",
    "ambition_lists.view_cxrtype",
    "ambition_lists.view_day14medication",
    "ambition_lists.view_infiltratelocation",
    "ambition_lists.view_medication",
    "ambition_lists.view_misseddoses",
    "ambition_lists.view_neurological",
    "ambition_lists.view_otherdrug",
    "ambition_lists.view_saereason",
    "ambition_lists.view_significantnewdiagnosis",
    "ambition_lists.view_symptom",
    "ambition_prn.add_amphotericinmisseddoses",
    "ambition_prn.add_fluconazolemisseddoses",
    "ambition_prn.add_flucytosinemisseddoses",
    "ambition_prn.add_onschedule",
    "ambition_prn.add_onschedulew10",
    "ambition_prn.add_protocoldeviationviolation",
    "ambition_prn.add_significantdiagnoses",
    "ambition_prn.add_studyterminationconclusion",
    "ambition_prn.add_studyterminationconclusionw10",
    "ambition_prn.change_amphotericinmisseddoses",
    "ambition_prn.change_fluconazolemisseddoses",
    "ambition_prn.change_flucytosinemisseddoses",
    "ambition_prn.change_onschedule",
    "ambition_prn.change_onschedulew10",
    "ambition_prn.change_protocoldeviationviolation",
    "ambition_prn.change_significantdiagnoses",
    "ambition_prn.change_studyterminationconclusion",
    "ambition_prn.change_studyterminationconclusionw10",
    "ambition_prn.delete_amphotericinmisseddoses",
    "ambition_prn.delete_fluconazolemisseddoses",
    "ambition_prn.delete_flucytosinemisseddoses",
    "ambition_prn.delete_onschedule",
    "ambition_prn.delete_onschedulew10",
    "ambition_prn.delete_protocoldeviationviolation",
    "ambition_prn.delete_significantdiagnoses",
    "ambition_prn.delete_studyterminationconclusion",
    "ambition_prn.delete_studyterminationconclusionw10",
    "ambition_prn.view_amphotericinmisseddoses",
    "ambition_prn.view_fluconazolemisseddoses",
    "ambition_prn.view_flucytosinemisseddoses",
    "ambition_prn.view_historicalamphotericinmisseddoses",
    "ambition_prn.view_historicalfluconazolemisseddoses",
    "ambition_prn.view_historicalflucytosinemisseddoses",
    "ambition_prn.view_historicalonschedule",
    "ambition_prn.view_historicalonschedulew10",
    "ambition_prn.view_historicalprotocoldeviationviolation",
    "ambition_prn.view_historicalsignificantdiagnoses",
    "ambition_prn.view_historicalstudyterminationconclusion",
    "ambition_prn.view_historicalstudyterminationconclusionw10",
    "ambition_prn.view_onschedule",
    "ambition_prn.view_onschedulew10",
    "ambition_prn.view_protocoldeviationviolation",
    "ambition_prn.view_significantdiagnoses",
    "ambition_prn.view_studyterminationconclusion",
    "ambition_prn.view_studyterminationconclusionw10",
    "ambition_subject.add_amphotericinmisseddoses",
    "ambition_subject.add_bloodresult",
    "ambition_subject.add_education",
    "ambition_subject.add_educationhoh",
    "ambition_subject.add_fluconazolemisseddoses",
    "ambition_subject.add_flucytosinemisseddoses",
    "ambition_subject.add_followup",
    "ambition_subject.add_followupdiagnoses",
    "ambition_subject.add_lumbarpuncturecsf",
    "ambition_subject.add_medicalexpenses",
    "ambition_subject.add_medicalexpensestwo",
    "ambition_subject.add_medicalexpensestwodetail",
    "ambition_subject.add_microbiology",
    "ambition_subject.add_patienthistory",
    "ambition_subject.add_pkpdcrf",
    "ambition_subject.add_pkpdextrasamples",
    "ambition_subject.add_previousopportunisticinfection",
    "ambition_subject.add_radiology",
    "ambition_subject.add_significantdiagnoses",
    "ambition_subject.add_subjectrequisition",
    "ambition_subject.add_subjectvisit",
    "ambition_subject.add_week16",
    "ambition_subject.add_week2",
    "ambition_subject.add_week4",
    "ambition_subject.add_week4diagnoses",
    "ambition_subject.change_amphotericinmisseddoses",
    "ambition_subject.change_bloodresult",
    "ambition_subject.change_education",
    "ambition_subject.change_educationhoh",
    "ambition_subject.change_fluconazolemisseddoses",
    "ambition_subject.change_flucytosinemisseddoses",
    "ambition_subject.change_followup",
    "ambition_subject.change_followupdiagnoses",
    "ambition_subject.change_lumbarpuncturecsf",
    "ambition_subject.change_medicalexpenses",
    "ambition_subject.change_medicalexpensestwo",
    "ambition_subject.change_medicalexpensestwodetail",
    "ambition_subject.change_microbiology",
    "ambition_subject.change_patienthistory",
    "ambition_subject.change_pkpdcrf",
    "ambition_subject.change_pkpdextrasamples",
    "ambition_subject.change_previousopportunisticinfection",
    "ambition_subject.change_radiology",
    "ambition_subject.change_significantdiagnoses",
    "ambition_subject.change_subjectrequisition",
    "ambition_subject.change_subjectvisit",
    "ambition_subject.change_week16",
    "ambition_subject.change_week2",
    "ambition_subject.change_week4",
    "ambition_subject.change_week4diagnoses",
    "ambition_subject.delete_amphotericinmisseddoses",
    "ambition_subject.delete_bloodresult",
    "ambition_subject.delete_education",
    "ambition_subject.delete_educationhoh",
    "ambition_subject.delete_fluconazolemisseddoses",
    "ambition_subject.delete_flucytosinemisseddoses",
    "ambition_subject.delete_followup",
    "ambition_subject.delete_followupdiagnoses",
    "ambition_subject.delete_lumbarpuncturecsf",
    "ambition_subject.delete_medicalexpenses",
    "ambition_subject.delete_medicalexpensestwo",
    "ambition_subject.delete_medicalexpensestwodetail",
    "ambition_subject.delete_microbiology",
    "ambition_subject.delete_patienthistory",
    "ambition_subject.delete_pkpdcrf",
    "ambition_subject.delete_pkpdextrasamples",
    "ambition_subject.delete_previousopportunisticinfection",
    "ambition_subject.delete_radiology",
    "ambition_subject.delete_significantdiagnoses",
    "ambition_subject.delete_subjectrequisition",
    "ambition_subject.delete_subjectvisit",
    "ambition_subject.delete_week16",
    "ambition_subject.delete_week2",
    "ambition_subject.delete_week4",
    "ambition_subject.delete_week4diagnoses",
    "ambition_subject.view_amphotericinmisseddoses",
    "ambition_subject.view_bloodresult",
    "ambition_subject.view_education",
    "ambition_subject.view_educationhoh",
    "ambition_subject.view_fluconazolemisseddoses",
    "ambition_subject.view_flucytosinemisseddoses",
    "ambition_subject.view_followup",
    "ambition_subject.view_followupdiagnoses",
    "ambition_subject.view_historicalamphotericinmisseddoses",
    "ambition_subject.view_historicalbloodresult",
    "ambition_subject.view_historicaleducation",
    "ambition_subject.view_historicaleducationhoh",
    "ambition_subject.view_historicalfluconazolemisseddoses",
    "ambition_subject.view_historicalflucytosinemisseddoses",
    "ambition_subject.view_historicalfollowup",
    "ambition_subject.view_historicalfollowupdiagnoses",
    "ambition_subject.view_historicallumbarpuncturecsf",
    "ambition_subject.view_historicalmedicalexpenses",
    "ambition_subject.view_historicalmedicalexpensestwo",
    "ambition_subject.view_historicalmedicalexpensestwodetail",
    "ambition_subject.view_historicalmicrobiology",
    "ambition_subject.view_historicalpatienthistory",
    "ambition_subject.view_historicalpkpdcrf",
    "ambition_subject.view_historicalpkpdextrasamples",
    "ambition_subject.view_historicalpreviousopportunisticinfection",
    "ambition_subject.view_historicalradiology",
    "ambition_subject.view_historicalsignificantdiagnoses",
    "ambition_subject.view_historicalsubjectrequisition",
    "ambition_subject.view_historicalsubjectvisit",
    "ambition_subject.view_historicalweek16",
    "ambition_subject.view_historicalweek2",
    "ambition_subject.view_historicalweek4",
    "ambition_subject.view_historicalweek4diagnoses",
    "ambition_subject.view_lumbarpuncturecsf",
    "ambition_subject.view_medicalexpenses",
    "ambition_subject.view_medicalexpensestwo",
    "ambition_subject.view_medicalexpensestwodetail",
    "ambition_subject.view_microbiology",
    "ambition_subject.view_patienthistory",
    "ambition_subject.view_pkpdcrf",
    "ambition_subject.view_pkpdextrasamples",
    "ambition_subject.view_previousopportunisticinfection",
    "ambition_subject.view_radiology",
    "ambition_subject.view_significantdiagnoses",
    "ambition_subject.view_subjectrequisition",
    "ambition_subject.view_subjectvisit",
    "ambition_subject.view_week16",
    "ambition_subject.view_week2",
    "ambition_subject.view_week4",
    "ambition_subject.view_week4diagnoses",
    "edc_dashboard.view_ae_listboard",
    "edc_dashboard.view_screening_listboard",
    "edc_dashboard.view_subject_listboard",
    "edc_dashboard.view_tmg_listboard",
    "edc_navbar.nav_ae_section",
    "edc_navbar.nav_screening_section",
    "edc_navbar.nav_subject_section",
    "edc_navbar.nav_tmg_section",
]
clinic.sort()
